==> deepin-deepinid-plugin_2.0.8.tar.xz: BUILD/translations/dcc-deepinid-plugin_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>LoginInfoPage</name>
    <message>
        <source>Edit account</source>
        <translation>編輯帳號訊息</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>退出登入</translation>
    </message>
    <message>
        <source>The nickname must be 1~32 characters long</source>
        <translation>暱稱長度必須為1~32個字元</translation>
    </message>
    <message>
        <source>The full name is too long</source>
        <translation>名稱過長</translation>
    </message>
    <message>
        <source>Mainland China</source>
        <translation>中國大陸</translation>
    </message>
    <message>
        <source>Other regions</source>
        <translation>其他地區</translation>
    </message>
</context>
<context>
    <name>SyncModule</name>
    <message>
        <source>deepin ID</source>
        <translation>deepin ID</translation>
    </message>
    <message>
        <source>UOS ID</source>
        <translation>UOS ID</translation>
    </message>
    <message>
        <source>Cloud sync, app store and etc</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TransString</name>
    <message>
        <source>deepin Cloud Sync</source>
        <translation>deepin Cloud同步</translation>
    </message>
    <message>
        <source>Subject to your local laws and regulations, it is currently unavailable in your region.</source>
        <translation>受限於您當地的法律法規，UOS Cloud暫未覆蓋您所在地區，敬請期待。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Securely store system settings and personal data in the cloud, and keep them in sync across devices.</source>
        <translation>將您的系統設定和個人訊息安全地儲存在雲端，並在您不同的裝置上保持同步。</translation>
    </message>
    <message>
        <source>System Settings</source>
        <translation>系統設定</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>滑鼠</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>任務欄</translation>
    </message>
    <message>
        <source>Launcher</source>
        <translation>啟動器</translation>
    </message>
    <message>
        <source>Wallpaper</source>
        <translation>桌布</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>主題</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>取消全選</translation>
    </message>
    <message>
        <source>Clear cloud data</source>
        <translation>清除雲端資料</translation>
    </message>
    <message>
        <source>Are you sure you want to clear your system settings and personal data saved in the cloud?</source>
        <translation>確定要清除您儲存在雲端的系統設定和個人資料嗎？</translation>
    </message>
    <message>
        <source>Once the data is cleared, it cannot be recovered!</source>
        <translation>資料清除後將無法復原！</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清 除</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation>正在同步，請稍候...</translation>
    </message>
    <message>
        <source>Last sync: %1</source>
        <translation>最近同步時間：%1</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
    <message>
        <source>Link local accounts to deepin ID</source>
        <translation>deepin ID綁定本機帳戶</translation>
    </message>
    <message>
        <source>If linked, you can use deepin ID to log in and reset passwords of local accounts. Switch it off to get them unlinked.</source>
        <translation>綁定本機帳戶，以使用deepin ID登入本機帳戶和重設本機帳戶密碼。您可以透過關閉開關以解除綁定。</translation>
    </message>
    <message>
        <source>Trusted devices</source>
        <translation>受信任裝置</translation>
    </message>
    <message>
        <source>Manage trusted devices to keep your deepin ID secure.</source>
        <translation>管理受信任的裝置，以確保您的deepin ID安全性。</translation>
    </message>
    <message>
        <source>OS version: %1</source>
        <translation>系統版本：%1</translation>
    </message>
    <message>
        <source>In use</source>
        <translation>目前裝置</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Are you sure you want to
remove this device from trusted devices?</source>
        <translation>確定從信任裝置中移除該裝置？</translation>
    </message>
    <message>
        <source>Cloud Service of deepin ID</source>
        <translation>deepin ID雲服務</translation>
    </message>
    <message>
        <source>Manage your deepin ID and sync your personal data across devices.
Sign in to deepin ID to get personalized features and services of Browser, App Store, Support, and more.</source>
        <translation>管理您的deepin ID，將您的個人資料在不同裝置之間同步。
登入deepin ID以獲取瀏覽器、應用商店、服務與支援等眾多應用的個性功能和服務。</translation>
    </message>
    <message>
        <source>Sign In to deepin ID</source>
        <translation>登入deepin ID</translation>
    </message>
    <message>
        <source>deepin Cloud</source>
        <translation>deepin Cloud</translation>
    </message>
    <message>
        <source>Devices and Local Accounts</source>
        <translation>裝置與本機帳戶</translation>
    </message>
    <message>
        <source>Password and Security</source>
        <translation>密碼與安全性</translation>
    </message>
    <message>
        <source>The feature is not available at present, please activate your system first</source>
        <translation>目前系統未啟用，暫無法使用該功能</translation>
    </message>
    <message>
        <source>Trusted phone numbers and email addresses</source>
        <translation>受信任的手機號碼和信箱</translation>
    </message>
    <message>
        <source>Use the trusted mobile number or email address to sign in to deepin ID, and verify sensitive operations if they are performed on deepin ID.</source>
        <translation>透過受信任的手機和信箱登入您的deepin ID，並在帳號進行敏感操作時做可信驗證。</translation>
    </message>
    <message>
        <source>Link phone number to deepin ID</source>
        <translation>deepin ID手機號碼綁定</translation>
    </message>
    <message>
        <source>Link email address to deepin ID</source>
        <translation>deepin ID信箱綁定</translation>
    </message>
    <message>
        <source>Link third-party accounts</source>
        <translation>第三方帳號綁定</translation>
    </message>
    <message>
        <source>Securely and quickly log in to your deepin ID and local account by scanning the QR code with the linked WeChat.</source>
        <translation>透過關聯微信掃碼，安全且快速的登入您的deepin ID和本機帳戶。</translation>
    </message>
    <message>
        <source>If unlinked, you will not be able to use WeChat to sign in to deepin ID.</source>
        <translation>解除與該微信的綁定關係，將不能使用微信掃碼登入。</translation>
    </message>
    <message>
        <source>Are you sure you want to unlink it?</source>
        <translation>確定解綁？</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼管理</translation>
    </message>
    <message>
        <source>Change your deepin ID password regularly to ensure its security.</source>
        <translation>定期更新deepin ID密碼，以確保帳戶安全性。</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>修改密碼</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>密碼修改成功</translation>
    </message>
    <message>
        <source>Operation failed, please try later</source>
        <translation>操作失敗，請稍後再試</translation>
    </message>
    <message>
        <source>Operation Successful</source>
        <translation>操作成功</translation>
    </message>
    <message>
        <source>Reset password successfully</source>
        <translation>密碼重設成功</translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation>請輸入您的手機號碼</translation>
    </message>
    <message>
        <source>Email address</source>
        <translation>請輸入您的信箱</translation>
    </message>
    <message>
        <source>Enter a correct phone number</source>
        <translation>請輸入正確的手機號碼</translation>
    </message>
    <message>
        <source>Enter a correct email address</source>
        <translation>請輸入正確的信箱</translation>
    </message>
    <message>
        <source>Use another phone number</source>
        <translation>更換手機號碼</translation>
    </message>
    <message>
        <source>Use another email address</source>
        <translation>更換信箱</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>綁定</translation>
    </message>
    <message>
        <source>Unlink</source>
        <translation>解綁</translation>
    </message>
    <message>
        <source>Unlinked</source>
        <translation>未綁定</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>修改</translation>
    </message>
    <message>
        <source>Wrong password, %1 chances left</source>
        <translation>密碼錯誤，您還可以嘗試%1次</translation>
    </message>
    <message>
        <source>The login error has reached the limit today. You can reset the password and try again.</source>
        <translation>密碼錯誤已達今日上限，可重設密碼再試</translation>
    </message>
    <message>
        <source>The phone number has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>該手機號碼已綁定帳號%1，請確認後選擇以下操作</translation>
    </message>
    <message>
        <source>The email address has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>該信箱已綁定帳號%1，請確認後選擇以下操作</translation>
    </message>
    <message>
        <source>Security Verification</source>
        <translation>安全驗證</translation>
    </message>
    <message>
        <source>The action is sensitive, please enter the login password first</source>
        <translation>您正在進行敏感操作，請進行登入密碼認證</translation>
    </message>
    <message>
        <source>Change deepin ID password</source>
        <translation>deepin ID密碼修改</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
    <message>
        <source>Link to current deepin ID</source>
        <translation>換綁本帳號</translation>
    </message>
    <message>
        <source>Set a Password</source>
        <translation>設定密碼</translation>
    </message>
    <message>
        <source>Get Code</source>
        <translation>獲取驗證碼</translation>
    </message>
    <message>
        <source>Verification code</source>
        <translation>請輸入驗證碼</translation>
    </message>
    <message>
        <source>Resend (%1s)</source>
        <translation>重新髮送 (%1s)</translation>
    </message>
    <message>
        <source>Enter a correct verification code</source>
        <translation>請輸入正確的驗證碼</translation>
    </message>
    <message>
        <source>Link WeChat to deepin ID</source>
        <translation>deepin ID微信綁定</translation>
    </message>
    <message>
        <source>Scan QR code with WeChat</source>
        <translation>請使用微信掃碼</translation>
    </message>
    <message>
        <source>Password must contain numbers and letters</source>
        <translation>密碼必須包含數字和字母</translation>
    </message>
    <message>
        <source>Password must be between 8 and 64 characters</source>
        <translation>密碼長度必須為8~64個字元</translation>
    </message>
    <message>
        <source>8-64 characters</source>
        <translation>請輸入8-64位密碼</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>兩次密碼輸入不一致</translation>
    </message>
    <message>
        <source>Repeat the password</source>
        <translation>請再次輸入密碼</translation>
    </message>
    <message>
        <source>8-64 characters, including uppercase or lowercase English letters and numbers</source>
        <translation>密碼由8-64位大小寫字母和數字組成</translation>
    </message>
    <message>
        <source>Invalid nickname, please enter a new one</source>
        <translation>暱稱不符合規範，請重新輸入</translation>
    </message>
    <message>
        <source>The nickname cannot contain special characters (&apos;&lt;&gt;&amp;&quot;) and whitespaces</source>
        <translation>暱稱不能包含&lt;、&gt;、&amp;、&apos;、&quot;和空格</translation>
    </message>
    <message>
        <source>The nickname can be modified only once a day</source>
        <translation>暱稱每天僅可修改一次</translation>
    </message>
</context>
</TS>

==> deepin-deepinid-plugin_2.0.9.tar.xz: BUILD/translations/dcc-deepinid-plugin_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>LoginInfoPage</name>
    <message>
        <source>Edit account</source>
        <translation>編輯帳號訊息</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>退出登入</translation>
    </message>
    <message>
        <source>The nickname must be 1~32 characters long</source>
        <translation>暱稱長度必須為1~32個字元</translation>
    </message>
    <message>
        <source>The full name is too long</source>
        <translation>名稱過長</translation>
    </message>
    <message>
        <source>Mainland China</source>
        <translation>中國大陸</translation>
    </message>
    <message>
        <source>Other regions</source>
        <translation>其他地區</translation>
    </message>
</context>
<context>
    <name>SyncModule</name>
    <message>
        <source>deepin ID</source>
        <translation>deepin ID</translation>
    </message>
    <message>
        <source>UOS ID</source>
        <translation>UOS ID</translation>
    </message>
    <message>
        <source>Cloud sync, app store and etc</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TransString</name>
    <message>
        <source>deepin Cloud Sync</source>
        <translation>deepin Cloud同步</translation>
    </message>
    <message>
        <source>Subject to your local laws and regulations, it is currently unavailable in your region.</source>
        <translation>受限於您當地的法律法規，UOS Cloud暫未覆蓋您所在地區，敬請期待。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Securely store system settings and personal data in the cloud, and keep them in sync across devices.</source>
        <translation>將您的系統設定和個人訊息安全地儲存在雲端，並在您不同的裝置上保持同步。</translation>
    </message>
    <message>
        <source>System Settings</source>
        <translation>系統設定</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>滑鼠</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>任務欄</translation>
    </message>
    <message>
        <source>Launcher</source>
        <translation>啟動器</translation>
    </message>
    <message>
        <source>Wallpaper</source>
        <translation>桌布</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>主題</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>取消全選</translation>
    </message>
    <message>
        <source>Clear cloud data</source>
        <translation>清除雲端資料</translation>
    </message>
    <message>
        <source>Are you sure you want to clear your system settings and personal data saved in the cloud?</source>
        <translation>確定要清除您儲存在雲端的系統設定和個人資料嗎？</translation>
    </message>
    <message>
        <source>Once the data is cleared, it cannot be recovered!</source>
        <translation>資料清除後將無法復原！</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清 除</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation>正在同步，請稍候...</translation>
    </message>
    <message>
        <source>Last sync: %1</source>
        <translation>最近同步時間：%1</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
    <message>
        <source>Link local accounts to deepin ID</source>
        <translation>deepin ID綁定本機帳戶</translation>
    </message>
    <message>
        <source>If linked, you can use deepin ID to log in and reset passwords of local accounts. Switch it off to get them unlinked.</source>
        <translation>綁定本機帳戶，以使用deepin ID登入本機帳戶和重設本機帳戶密碼。您可以透過關閉開關以解除綁定。</translation>
    </message>
    <message>
        <source>Trusted devices</source>
        <translation>受信任裝置</translation>
    </message>
    <message>
        <source>Manage trusted devices to keep your deepin ID secure.</source>
        <translation>管理受信任的裝置，以確保您的deepin ID安全性。</translation>
    </message>
    <message>
        <source>OS version: %1</source>
        <translation>系統版本：%1</translation>
    </message>
    <message>
        <source>In use</source>
        <translation>目前裝置</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Are you sure you want to
remove this device from trusted devices?</source>
        <translation>確定從信任裝置中移除該裝置？</translation>
    </message>
    <message>
        <source>Cloud Service of deepin ID</source>
        <translation>deepin ID雲服務</translation>
    </message>
    <message>
        <source>Manage your deepin ID and sync your personal data across devices.
Sign in to deepin ID to get personalized features and services of Browser, App Store, and more.</source>
        <translation>管理您的deepin ID，將您的個人資料在不同裝置之間同步。
登入deepin ID以獲取瀏覽器、應用商店等眾多應用的個性功能和服務。</translation>
    </message>
    <message>
        <source>Sign In to deepin ID</source>
        <translation>登入deepin ID</translation>
    </message>
    <message>
        <source>deepin Cloud</source>
        <translation>deepin Cloud</translation>
    </message>
    <message>
        <source>Devices and Local Accounts</source>
        <translation>裝置與本機帳戶</translation>
    </message>
    <message>
        <source>Password and Security</source>
        <translation>密碼與安全性</translation>
    </message>
    <message>
        <source>The feature is not available at present, please activate your system first</source>
        <translation>目前系統未啟用，暫無法使用該功能</translation>
    </message>
    <message>
        <source>Trusted phone numbers and email addresses</source>
        <translation>受信任的手機號碼和信箱</translation>
    </message>
    <message>
        <source>Use the trusted mobile number or email address to sign in to deepin ID, and verify sensitive operations if they are performed on deepin ID.</source>
        <translation>透過受信任的手機和信箱登入您的deepin ID，並在帳號進行敏感操作時做可信驗證。</translation>
    </message>
    <message>
        <source>Link phone number to deepin ID</source>
        <translation>deepin ID手機號碼綁定</translation>
    </message>
    <message>
        <source>Link email address to deepin ID</source>
        <translation>deepin ID信箱綁定</translation>
    </message>
    <message>
        <source>Link third-party accounts</source>
        <translation>第三方帳號綁定</translation>
    </message>
    <message>
        <source>Securely and quickly log in to your deepin ID and local account by scanning the QR code with the linked WeChat.</source>
        <translation>透過關聯微信掃碼，安全且快速的登入您的deepin ID和本機帳戶。</translation>
    </message>
    <message>
        <source>If unlinked, you will not be able to use WeChat to sign in to deepin ID.</source>
        <translation>解除與該微信的綁定關係，將不能使用微信掃碼登入。</translation>
    </message>
    <message>
        <source>Are you sure you want to unlink it?</source>
        <translation>確定解綁？</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼管理</translation>
    </message>
    <message>
        <source>Change your deepin ID password regularly to ensure its security.</source>
        <translation>定期更新deepin ID密碼，以確保帳戶安全性。</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>修改密碼</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>密碼修改成功</translation>
    </message>
    <message>
        <source>Operation failed, please try later</source>
        <translation>操作失敗，請稍後再試</translation>
    </message>
    <message>
        <source>Operation Successful</source>
        <translation>操作成功</translation>
    </message>
    <message>
        <source>Reset password successfully</source>
        <translation>密碼重設成功</translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation>請輸入您的手機號碼</translation>
    </message>
    <message>
        <source>Email address</source>
        <translation>請輸入您的信箱</translation>
    </message>
    <message>
        <source>Enter a correct phone number</source>
        <translation>請輸入正確的手機號碼</translation>
    </message>
    <message>
        <source>Enter a correct email address</source>
        <translation>請輸入正確的信箱</translation>
    </message>
    <message>
        <source>Use another phone number</source>
        <translation>更換手機號碼</translation>
    </message>
    <message>
        <source>Use another email address</source>
        <translation>更換信箱</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>綁定</translation>
    </message>
    <message>
        <source>Unlink</source>
        <translation>解綁</translation>
    </message>
    <message>
        <source>Unlinked</source>
        <translation>未綁定</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>修改</translation>
    </message>
    <message>
        <source>Wrong password, %1 chances left</source>
        <translation>密碼錯誤，您還可以嘗試%1次</translation>
    </message>
    <message>
        <source>The login error has reached the limit today. You can reset the password and try again.</source>
        <translation>密碼錯誤已達今日上限，可重設密碼再試</translation>
    </message>
    <message>
        <source>The phone number has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>該手機號碼已綁定帳號%1，請確認後選擇以下操作</translation>
    </message>
    <message>
        <source>The email address has been linked to deepin ID: %1.
Please check and choose one action below.</source>
        <translation>該信箱已綁定帳號%1，請確認後選擇以下操作</translation>
    </message>
    <message>
        <source>Security Verification</source>
        <translation>安全驗證</translation>
    </message>
    <message>
        <source>The action is sensitive, please enter the login password first</source>
        <translation>您正在進行敏感操作，請進行登入密碼認證</translation>
    </message>
    <message>
        <source>Change deepin ID password</source>
        <translation>deepin ID密碼修改</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
    <message>
        <source>Link to current deepin ID</source>
        <translation>換綁本帳號</translation>
    </message>
    <message>
        <source>Set a Password</source>
        <translation>設定密碼</translation>
    </message>
    <message>
        <source>Get Code</source>
        <translation>獲取驗證碼</translation>
    </message>
    <message>
        <source>Verification code</source>
        <translation>請輸入驗證碼</translation>
    </message>
    <message>
        <source>Resend (%1s)</source>
        <translation>重新髮送 (%1s)</translation>
    </message>
    <message>
        <source>Enter a correct verification code</source>
        <translation>請輸入正確的驗證碼</translation>
    </message>
    <message>
        <source>Link WeChat to deepin ID</source>
        <translation>deepin ID微信綁定</translation>
    </message>
    <message>
        <source>Scan QR code with WeChat</source>
        <translation>請使用微信掃碼</translation>
    </message>
    <message>
        <source>Password must contain numbers and letters</source>
        <translation>密碼必須包含數字和字母</translation>
    </message>
    <message>
        <source>Password must be between 8 and 64 characters</source>
        <translation>密碼長度必須為8~64個字元</translation>
    </message>
    <message>
        <source>8-64 characters</source>
        <translation>請輸入8-64位密碼</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>兩次密碼輸入不一致</translation>
    </message>
    <message>
        <source>Repeat the password</source>
        <translation>請再次輸入密碼</translation>
    </message>
    <message>
        <source>8-64 characters, including uppercase or lowercase English letters and numbers</source>
        <translation>密碼由8-64位大小寫字母和數字組成</translation>
    </message>
    <message>
        <source>Invalid nickname, please enter a new one</source>
        <translation>暱稱不符合規範，請重新輸入</translation>
    </message>
    <message>
        <source>The nickname cannot contain special characters (&apos;&lt;&gt;&amp;&quot;) and whitespaces</source>
        <translation>暱稱不能包含&lt;、&gt;、&amp;、&apos;、&quot;和空格</translation>
    </message>
    <message>
        <source>The nickname can be modified only once a day</source>
        <translation>暱稱每天僅可修改一次</translation>
    </message>
</context>
</TS>
